#!/bin/sh
# Usage:  dualize2.sh input_file [output_file]
# Author: Takahisa Toda
# Description: given a DNF of a Boolean function, this software computes the DNF of all prime implicants of the dual function.
# Note: to use this script, obtain consensus from http://www.sd.is.uec.ac.jp/toda/code/dbtdd.html and 
#       clasp from http://www.cs.uni-potsdam.de/clasp/ and set PATH_TO_CONSENSUS and PATH_TO_CLASP

PATH_TO_CONSENSUS="."
PATH_TO_CLASP="."

if [ $# -lt 1 -o $# -gt 2 ]; then
        echo "Usage: dualize2.sh input_file [output_file]"
        exit 1
fi

input_file=$1

if [ $# -eq 2 ]; then
    output_file=$2
fi

tmpfile1=$(mktemp);
tmpfile2=$(mktemp);

echo "${PATH_TO_CLASP}/clasp 0 $input_file > $tmpfile1"
${PATH_TO_CLASP}/clasp 0 $input_file > $tmpfile1
if [ $? -ne 30 ]; then
        echo "clasp execution failed"
        exit 1
fi
echo ""
echo ""

grep '^v' $tmpfile1 | sed 's/^v//' > $tmpfile2

echo "${PATH_TO_CONSENSUS}/consensus $tmpfile2 $output_file"
${PATH_TO_CONSENSUS}/consensus $tmpfile2 $output_file
if [ $? -ne 0 ]; then
        echo "consensus execution failed"
        exit 1
fi

rm $tmpfile1 $tmpfile2
